@@ -10,13 +10,17 @@ from zipfile import ZIP_DEFLATED, ZipFile
 
 from pydantic.dataclasses import dataclass
 
+from metaphor.common.event_util import EventUtil
+from metaphor.common.logger import LOG_FILE, debug_files, get_logger
+from metaphor.common.sink import Sink
+from metaphor.common.storage import (
+    BaseStorage,
+    LocalStorage,
+    S3Storage,
+    S3StorageConfig,
+)
 from metaphor.models.crawler_run_metadata import CrawlerRunMetadata
 
-from .event_util import EventUtil
-from .logger import LOG_FILE, get_logger
-from .sink import Sink
-from .storage import BaseStorage, LocalStorage, S3Storage, S3StorageConfig
-
 logger = get_logger()
 
 
@@ -83,10 +87,15 @@ class FileSink(Sink):
         logging.shutdown()
 
         _, zip_file = tempfile.mkstemp(suffix=".zip")
-        timestamp = datetime.now(timezone.utc).isoformat()
-        log_filename = f"{path.basename(self.path)}_{timestamp}.log"
+        dir_name = datetime.now(timezone.utc).strftime("%Y-%m-%d %H-%M-%S")
+
         with ZipFile(zip_file, "w", ZIP_DEFLATED) as file:
-            file.write(LOG_FILE, arcname=log_filename)
+            arcname = f"{dir_name}/{path.basename(self.path)}.log"
+            file.write(LOG_FILE, arcname=arcname)
+
+            for debug_file in debug_files:
+                arcname = f"{dir_name}/{path.basename(debug_file)}"
+                file.write(debug_file, arcname=arcname)
 
         with open(zip_file, "rb") as file:
             self._storage.write_file(f"{self.path}/log.zip", file.read(), True)
