@@ -3,7 +3,7 @@ from typing import Collection, Dict, List, Union
 
 from metaphor.common.base_extractor import BaseExtractor
 from metaphor.common.event_util import ENTITY_TYPES
-from metaphor.common.logger import get_logger
+from metaphor.common.logger import add_debug_file, get_logger
 from metaphor.dbt.config import DbtRunConfig
 from metaphor.models.crawler_run_metadata import Platform
 from metaphor.models.metadata_change_event import (
@@ -17,6 +17,7 @@ from .catalog_parser_v1 import CatalogParserV1
 from .manifest_parser_v3 import ManifestParserV3
 from .manifest_parser_v5 import ManifestParserV5
 from .manifest_parser_v6 import ManifestParserV6
+from .manifest_parser_v7 import ManifestParserV7
 
 logger = get_logger()
 
@@ -42,6 +43,10 @@ class DbtExtractor(BaseExtractor):
         self._virtual_views: Dict[str, VirtualView] = {}
         self._metrics: Dict[str, Metric] = {}
 
+        add_debug_file(config.manifest)
+        if config.catalog:
+            add_debug_file(config.catalog)
+
     async def extract(self) -> Collection[ENTITY_TYPES]:
 
         logger.info("Fetching metadata from DBT repo")
@@ -61,7 +66,9 @@ class DbtExtractor(BaseExtractor):
             .split(".")[0]
         )
 
-        manifest_parser: Union[ManifestParserV3, ManifestParserV5, ManifestParserV6]
+        manifest_parser: Union[
+            ManifestParserV3, ManifestParserV5, ManifestParserV6, ManifestParserV7
+        ]
         if schema_version in ("v1", "v2", "v3"):
             manifest_parser = ManifestParserV3(
                 self._config,
@@ -85,6 +92,14 @@ class DbtExtractor(BaseExtractor):
                 self._virtual_views,
                 self._metrics,
             )
+        elif schema_version == "v7":
+            manifest_parser = ManifestParserV7(
+                self._config,
+                self._data_platform,
+                self._datasets,
+                self._virtual_views,
+                self._metrics,
+            )
         else:
             raise ValueError(f"unsupported manifest schema '{schema_version}'")
 
