@@ -38,7 +38,8 @@ from .generated.dbt_manifest_v5 import (
     ParsedSourceDefinition,
 )
 from .util import (
-    build_docs_url,
+    build_metric_docs_url,
+    build_model_docs_url,
     build_source_code_url,
     get_ownerships_from_meta,
     get_tags_from_meta,
@@ -52,7 +53,7 @@ from .util import (
     init_virtual_view,
 )
 
-logger = get_logger(__name__)
+logger = get_logger()
 
 # compiled node has 'compiled_sql' field
 MODEL_NODE_TYPE = Union[CompiledModelNode, ParsedModelNode]
@@ -209,7 +210,7 @@ class ManifestParserV5:
             url=build_source_code_url(
                 self._project_source_url, model.original_file_path
             ),
-            docs_url=build_docs_url(self._docs_base_url, model.unique_id),
+            docs_url=build_model_docs_url(self._docs_base_url, model.unique_id),
             tags=model.tags,
             raw_sql=model.raw_sql,
             fields=[],
@@ -306,6 +307,7 @@ class ManifestParserV5:
                 MetricFilter(field=f.field, operator=f.operator, value=f.value)
                 for f in metric.filters
             ],
+            url=build_metric_docs_url(self._docs_base_url, metric.unique_id),
         )
 
         dbt_metric = metric_entity.dbt_metric
