@@ -16,6 +16,15 @@ class Ownership:
     email: str
 
 
+@dataclass
+class Description:
+    # The description to assign
+    description: str
+
+    # The author's email address
+    email: str
+
+
 @dataclass
 class DatasetGovernance:
     id: DeserializableDatasetLogicalID
@@ -24,6 +33,8 @@ class DatasetGovernance:
 
     tags: List[str] = dataclass_field(default_factory=lambda: [])
 
+    descriptions: List[Description] = dataclass_field(default_factory=lambda: [])
+
 
 @dataclass
 class ManualGovernanceConfig(BaseConfig):
