@@ -11,7 +11,7 @@ from metaphor.models.metadata_change_event import (
     MetadataChangeEvent,
 )
 
-logger = get_logger(__name__)
+logger = get_logger()
 
 
 class CustomMetadataExtractor(BaseExtractor):
